/******************************************************************************
 * 
 * Copyright 2012 - 2013 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/


package com.vektorsoft.demux.android.core;

import com.vektorsoft.demux.android.core.app.DMXAndroidApplication;
import com.vektorsoft.demux.core.app.DMXApplication;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.Filter;
import org.osgi.util.tracker.ServiceTracker;

/**
 * Activator for Android Core bundle. This activator will register Android implementations of {@link DMXApplication} and 
 * {@link DMXAdapter}.
 *
 * @author Vladimir Djurovic
 */
public class DMXAndroidCoreActivator implements BundleActivator {
    
    /** Service tracker for main activity service. */
    private ServiceTracker activityServiceTracker;

    @Override
    public void start(BundleContext bc) throws Exception {
        // register application service
        DMXApplication application = new DMXAndroidApplication();
        bc.registerService(DMXApplication.class, application, null);
        
        //start tracker for main activity service
        String filterString = "(objectClass=com.vektorsoft.demux.android.main.svc.DMXMainActivityService)";
        Filter filter = bc.createFilter(filterString);
        activityServiceTracker = new ServiceTracker(bc, filter, new ActivityServiceCustomizer(bc));
        activityServiceTracker.open();
    }

    @Override
    public void stop(BundleContext bc) throws Exception {
        activityServiceTracker.open();
    }

}
