/******************************************************************************
 * 
 * Copyright 2012 - 2014 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/


package com.vektorsoft.demux.core.common;

import com.vektorsoft.demux.core.mva.DMXController;
import com.vektorsoft.demux.core.mva.ExecutionException;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

/**
 * Controller used to bind properties of GUI components to model values. This controller is intended
 * to be used with property and event listeners in order to keep model in sync with states of GUI 
 * components.
 *
 * @author Vladimir Djurovic
 */
public class PropertBindingController implements DMXController{
    
    /**
     * Thread local storage for variable values.
     */
    private final ThreadLocal<Map<String, Object>> local = new ThreadLocal<Map<String, Object>>();

    @Override
    public String getNextViewId() {
        return null;
    }

    @Override
    public String getMapping() {
        return this.getClass().getName();
    }

    @Override
    public void updateFromModel(Map<String, Object> modelData) {
        // do nothing
    }

    @Override
    public Map<String, Object> updateModel() {
        return local.get();
    }

    @Override
    public Map<String, Object> getControllerDataMap() {
        return new HashMap<String, Object>();
    }

    @Override
    public Set<String> getControllerDataNames() {
        return new HashSet<String>();
    }

    @Override
    public void execute(Object... params) throws ExecutionException {
        String name = params[0].toString();
        Map<String, Object> map = new HashMap<String, Object>();
        map.put(name, params[1]);
        local.set(map);
    }

   

}
