/******************************************************************************
 * 
 * Copyright 2012 - 2013 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/


package com.vektorsoft.demux.core.extension.impl;

import com.vektorsoft.demux.core.extension.DMXExtendable;
import com.vektorsoft.demux.core.extension.DMXExtensionCallback;
import com.vektorsoft.demux.core.extension.DMXExtensionManager;
import com.vektorsoft.demux.core.mva.DMXController;
import com.vektorsoft.demux.core.mva.DMXView;
import com.vektorsoft.demux.core.mva.DMXViewManager;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * Default implementation of {@link DMXExtensionManager}.
 *
 * @author Vladimir Djurovic
 */
public final class DMXExtensionManagerImpl implements DMXExtensionManager {
    
    /** Map of callback interfaces. */
    private Map<String, DMXExtensionCallback> callbackMap;
    
    /**
     * Creates new instance.
     * 
     */
    public DMXExtensionManagerImpl(){
        callbackMap = new ConcurrentHashMap<String, DMXExtensionCallback>();
    }
    
    /**
     * <p>
     * Registers extension callback interface. This method will store callback in
     * local cache so it can be reused.
     * </p>
     * 
     * 
     * @param callback callback to register
     */
    @Override
    public void registerCallback(DMXExtensionCallback callback){
        String[] mappings = callback.getMappings();
        for(String mapping : mappings){
            callbackMap.put(mapping, callback);
        }
        
    }
    
    @Override
    public void registerExtendableController(DMXExtendable extendable) {
        if (!(extendable instanceof DMXController)) {
            throw new IllegalArgumentException("Parameter must be an instance of DMXController");
        }
        String mapping;
        mapping = ((DMXController) extendable).getMapping();
        if (callbackMap.containsKey(mapping)) {
            extendable.setExtensionCallback(callbackMap.get(mapping));
        }
    }

    @Override
    public void registerExtendableView(DMXExtendable view, DMXViewManager viewManager) {
        if (!(view instanceof DMXView)) {
            throw new IllegalArgumentException("Parameter must be an instance of DMXView");
        }
        
        String id = ((DMXView)view).getViewId();
        if (callbackMap.containsKey(id)) {
            viewManager.setViewExtensionCallback(id, callbackMap.get(id));
        }
    }
    
   

}
