/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */


package com.vektorsoft.demux.samples.extensions.android;

import android.content.Context;
import android.graphics.Color;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.vektorsoft.demux.android.core.app.DMXAndroidViewManager;
import com.vektorsoft.demux.android.core.resources.DMXAndroidResourceHandler;
import com.vektorsoft.demux.core.annotations.DMXModelData;
import com.vektorsoft.demux.core.annotations.DMXViewDeclaration;
import com.vektorsoft.demux.core.extension.DMXExtendable;
import com.vektorsoft.demux.core.extension.DMXExtensionCallback;
import com.vektorsoft.demux.core.mva.DMXAdapter;
import com.vektorsoft.demux.core.resources.ResourceHandlerType;

/**
 *
 * @author Vladimir Djurovic
 */
@DMXViewDeclaration (parentViewId = DMXAndroidViewManager.DMX_ANDROID_ROOT_VIEW , viewID = "extendableView")
public class AndroidExtendableView implements DMXExtendable {
    
    @DMXModelData
    private boolean status;
    
    private DMXAdapter adapter;
    private Context context;
    
    @DMXViewDeclaration.ViewUI
    private LinearLayout root;
    private LinearLayout hbox;
    private TextView helloView;
    private Button button;
    
    private SimpleViewCallback callback;
    private DMXAndroidResourceHandler handler;
    
    public AndroidExtendableView(Context context, DMXAdapter adapter){
        this.context = context;
        this.adapter = adapter;
        this.handler = adapter.getResourceManager().getResourceHandler(ResourceHandlerType.ANDROID);
    }
    
    @DMXViewDeclaration.Render
    public void render(){
        if(status){
            helloView.setTextColor(Color.GREEN);
        } else {
            helloView.setTextColor(Color.RED);
        }
        // render extension
        if(callback != null){
            callback.render();
        }
    }

    @Override
    public void setExtensionCallback(DMXExtensionCallback callback) {
        this.callback = (SimpleViewCallback)callback;
        if(this.callback.getSubviewRoot(context) != null){
            root.addView(this.callback.getSubviewRoot(context));
        }
    }

    @Override
    public String getCallbackClassName() {
        return SimpleViewCallback.class.getName();
    }

    @Override
    public DMXExtensionCallback getExtensionCallback() {
        return callback;
    }
    
    @DMXViewDeclaration.ConstructUI
    public void makeUI(){
         root = new LinearLayout(context);
        root.setOrientation(LinearLayout.VERTICAL);
        
        //first row
        hbox = new LinearLayout(context);
        hbox.setOrientation(LinearLayout.HORIZONTAL);
        
        helloView = new TextView(context);
        helloView.setText(handler.getString("base_label"));
        hbox.addView(helloView);
        
        button = new Button(context);
        button.setText("Click me");
        button.setOnClickListener(new View.OnClickListener() {

            @Override
            public void onClick(View view) {
                AndroidExtendableView.this.adapter.invokeController("extController", "param");
            }
        });
        hbox.addView(button);
        root.addView(hbox);
    }

    public LinearLayout getRoot() {
        return root;
    }

    public void setRoot(LinearLayout root) {
        this.root = root;
    }

    public void setStatus(boolean status) {
        this.status = status;
    }
    
    public boolean getStatus(){
        return status;
    }
    
}
